@@ -13,6 +13,8 @@ from .importTransactions import importTransactions
 from .importUsers import importUsers
 from .importCustomers import importCustomers
 from .importCards import importCards
+from .getCardIdByCardNumber import getCardIdByCardNumber
+from .importCardAttributes import importCardAttributes
 from .getUserId import getUserId
 from .addRole import addRole
 from .getUserId import getUserId
@@ -21,11 +23,21 @@ from .addFx import addFx
 from .createAccount import createAccount
 from .createBank import createBank
 from .createCustomer import createCustomer
+from .createConsent import createConsent
+from .createView import createView, possible_actions
+from .revokeConsent import revokeConsent
+from .answerConsent import answerConsent
+from .revokeConsent import revokeConsent
+from .getConsents import getConsents
+from .getConsentStatus import getConsentStatus
 from .linkUserToCustomer import linkUserToCustomer
 from .getBanks import getBanks
 from .getCards import getCards
+from .getCardById import getCardById
+from .getCardByCardNumber import getCardByCardNumber
 from .getAccountsHeld import getAccountsHeld
 from .getAccount import getAccountById
+from .getAccountTransactions import getAccountTransactions
 from .getCustomers import getCustomers
 from .deleteBranches import deleteBranches
 from .deleteCardById import deleteCardById
@@ -142,7 +154,7 @@ def getbanks():
   else:
     exit(req.text)
 
-@cli.command(help="🏦 Get list of cards at bank")
+@cli.command(help="💳 Get list of cards at bank")
 @click.option('--bank-id', prompt=True, default="gh.29.uk.x")
 def getcards(bank_id):
   req = getCards(bank_id=bank_id)
@@ -152,6 +164,28 @@ def getcards(bank_id):
   else:
     exit(req.text)
 
+@cli.command(help="💳 Get card by card number")
+@click.option('--bank-id', prompt=True, default="gh.29.uk.x")
+@click.option('--card-number', prompt=True, help="Use `obp getcards` to find cards")
+def getcardbynumber(bank_id,card_number):
+  req = getCardByCardNumber(bank_id=bank_id, card_number=card_number)
+  if req.status_code == 200:
+    pp = pprint.PrettyPrinter(width=41, compact=True)
+    click.echo(pp.pprint(json.loads(req.text)))
+  else:
+    exit(req.text)
+
+@cli.command(help="💳 Get card by id")
+@click.option('--bank-id', prompt=True, default="gh.29.uk.x")
+@click.option('--card-id', prompt=True)
+def getcardbyid(bank_id, card_id):
+  req = getCardById(bank_id=bank_id, card_id=card_id)
+  if req.status_code == 200:
+    pp = pprint.PrettyPrinter(width=41, compact=True)
+    click.echo(pp.pprint(json.loads(req.text)))
+  else:
+    exit(req.text)
+
 @cli.command(help="📁 Get list of accounts held")
 @click.option('--bank-id', prompt=True)
 def getaccountsheld(bank_id):
@@ -173,6 +207,19 @@ def getaccountbyid(bank_id, account_id):
   else:
     exit(req.text)
 
+@cli.command(help="📁 Get transactions for an account")
+@click.option('--bank-id', prompt=True, default="gh.29.uk.x")
+@click.option('--account-id', prompt=True, help="Use `obp getaccountsheld` to know account ids")
+@click.option('--view-name', prompt=True, default="owner")
+def getaccounttransactions(bank_id, account_id, view_name):
+  req = getAccountTransactions(bank_id=bank_id, account_id=account_id, 
+                              view_name=view_name)
+  if req.status_code == 200:
+    pp = pprint.PrettyPrinter(width=41, compact=True)
+    click.echo(pp.pprint(json.loads(req.text)))
+  else:
+    exit(req.text)
+
 @cli.command(help="👥 Get list of customers")
 @click.option('--bank-id', default="gh.29.uk.x", prompt=True)
 def getcustomers(bank_id):
@@ -294,6 +341,27 @@ def addcustomer(bank_id, username, customer_number, legal_name, title,
   else:
     exit(req.text)
 
+@cli.command(help="🧐 Add a view")
+@click.option('--bank-id', default="gh.29.uk.x", prompt=True)
+@click.option('--account-id', prompt=True)
+@click.option('--name', prompt=True, help="Example: Auditor")
+@click.option('--description', prompt=True)
+@click.option('--metadata-view', prompt=True, default="_test")
+@click.option('--which-alias-to-use', prompt=True, default="")
+@click.option('--is-public', type=bool, prompt=True, default=False)
+@click.option('--allowed-actions', prompt=True, help=possible_actions)
+def addview(bank_id, account_id, name, description, metadata_view, 
+            which_alias_to_use, is_public, allowed_actions):
+  req = createView(bank_id=bank_id, account_id=account_id, name=name, 
+                  description=description, 
+                  metadata_view=metadata_view, 
+                  which_alias_to_use=which_alias_to_use,
+                  is_public=is_public, allowed_actions=allowed_actions)
+  if req.status_code == 201 or req.status_code == 200:
+    click.echo(req.text)
+  else:
+    exit(req.text)
+
 @cli.command(help="🔗 Link user to a customer")
 @click.option('--bank-id', default="gh.29.uk.x", prompt=True)
 @click.option('--user-id', required=True, prompt=True)
@@ -320,6 +388,67 @@ def addrole(role_name, bank_id=None, user_id=None):
   else:
     exit(req.text)
 
+@cli.command(help="🚧 Add a consent")
+@click.option('--bank-id', prompt=True, default="gh.29.uk.x")
+@click.option('--consent_type', default="email", prompt=True, help="email|sms")
+@click.option('--consent_for', prompt=True, default="ALL_MY_ACCOUNTS")
+@click.option('--view', prompt=True, default="owner")
+@click.option('--email', prompt=True, default="")
+@click.option('--phone_number', prompt=True, default="")
+def createconsent(bank_id, consent_type, consent_for,
+                  view, email, phone_number):
+
+  req = createConsent(bank_id=bank_id, consent_type=consent_type, 
+                  consent_for=consent_for, view=view, email=email, 
+                  phone_number=phone_number)
+  if req.status_code == 201 or req.status_code == 200:
+    click.echo(req.text)
+  else:
+    exit(req.text)
+
+@cli.command(help="🚧 Get consents")
+@click.option('--bank-id', prompt=True, default="gh.29.uk.x")
+def getconsents(bank_id):
+
+  req = getConsents(bank_id=bank_id)
+  if req.status_code == 200:
+    click.echo(req.text)
+  else:
+    exit(req.text)
+
+@cli.command(help="🚧 Revoke consent")
+@click.option('--bank-id', prompt=True, default="gh.29.uk.x")
+@click.option('--consent-id', prompt=True)
+def revokeconsent(bank_id, consent_id):
+
+  req = revokeConsent(bank_id=bank_id, consent_id=consent_id)
+  if req.status_code == 200:
+    click.echo(req.text)
+  else:
+    exit(req.text)
+
+@cli.command(help="🚧 Answer consent")
+@click.option('--bank-id', prompt=True, default="gh.29.uk.x")
+@click.option('--consent-id', prompt=True)
+@click.option('--answer', prompt=True)
+def answerconsent(bank_id, consent_id, answer):
+
+  req = answerConsent(bank_id=bank_id, consent_id=consent_id, answer=answer)
+  if req.status_code == 200:
+    click.echo(req.text)
+  else:
+    exit(req.text)
+
+@cli.command(help="🚧 Get consent status- with certificate")
+@click.option('--consent-id', prompt=True)
+@click.option('--cert', type=click.File('r'), required=True, help="Certificate file")
+def getconsentstatus(consent_id, cert):
+  req = getConsentStatus(consent_id=consent_id, certificate=cert)
+  if req.status_code == 200:
+    click.echo(req.text)
+  else:
+    exit(req.text)
+
 @cli.command(help="📉 Add exchange rate (FX)")
 @click.option('--bank-id', required=True, prompt=True)
 @click.option('--from-currency', required=True, prompt=True)
@@ -377,6 +506,11 @@ def importtransactions(spreadsheet):
 def importcustomers(spreadsheet):
   req = importCustomers(spreadsheet)
 
+@cli.command(help="🚜 Import card attributes from spreadsheet template")
+@click.argument('spreadsheet', type=click.File('rb'), required=True)
+def importcardattribues(spreadsheet):
+  req = importCardAttributes(spreadsheet)
+
 @cli.command(help="🚜 Import cards from spreadsheet template")
 @click.argument('spreadsheet', type=click.File('rb'), required=True)
 def importcards(spreadsheet):
